@@ -14,7 +14,8 @@ class TestDataLoader(unittest.TestCase):
         for i in tfkit.tag.get_data_from_file_row(os.path.join(TestDataLoader.DATASET_DIR, 'tag_row.csv')):
             print(i)
         for i in tfkit.tag.loadRowTaggerDataset(os.path.join(TestDataLoader.DATASET_DIR, 'tag_row.csv'),
-                                                pretrained='bert-base-chinese', maxlen=128):
+                                                pretrained='voidful/albert_chinese_small', maxlen=128):
+            print(i)
             self.assertTrue(len(i['input']) < 512)
             self.assertTrue(len(i['target']) < 512)
 
@@ -23,20 +24,21 @@ class TestDataLoader(unittest.TestCase):
         for i in tfkit.tag.get_data_from_file_col(os.path.join(TestDataLoader.DATASET_DIR, 'tag_col.csv')):
             print(i)
         for i in tfkit.tag.loadColTaggerDataset(os.path.join(TestDataLoader.DATASET_DIR, 'tag_col.csv'),
-                                                pretrained='bert-base-chinese', maxlen=128):
+                                                pretrained='voidful/albert_chinese_small', maxlen=128):
             self.assertTrue(len(i['input']) < 512)
             self.assertTrue(len(i['target']) < 512)
 
     def testOnce(self):
 
-        tokenizer = BertTokenizer.from_pretrained('bert-base-chinese')
-        for i in tfkit.gen_once.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
+        tokenizer = BertTokenizer.from_pretrained('bert-base-uncased')
+        for i in tfkit.gen_once.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'gen_long.csv')):
             print(i)
-        for i in tfkit.gen_once.loadOnceDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
-                                                pretrained='bert-base-chinese',
+        for i in tfkit.gen_once.loadOnceDataset(os.path.join(TestDataLoader.DATASET_DIR, 'gen_long.csv'),
+                                                pretrained='bert-base-uncased',
                                                 maxlen=128):
             print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['input'])))
             print(tokenizer.convert_tokens_to_string(tokenizer.convert_ids_to_tokens(i['target'])))
+            print(i)
             self.assertTrue(len(i['input']) < 512)
             self.assertTrue(len(i['target']) < 512)
 
@@ -45,12 +47,13 @@ class TestDataLoader(unittest.TestCase):
 
         for i in tfkit.gen_onebyone.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv')):
             print(i)
-        maxlen = 512
+        maxlen = 100
         for likelihood in ['onebyone-neg', 'onebyone-pos', 'onebyone-both']:
             for i in tfkit.gen_onebyone.loadOneByOneDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
-                                                            pretrained='voidful/albert_chinese_tiny',
+                                                            pretrained_config='voidful/albert_chinese_tiny',
                                                             maxlen=maxlen, likelihood=likelihood):
                 start_pos = i['start']
+                print(i)
                 self.assertTrue(tokenizer.mask_token_id == i['input'][start_pos])
                 if 'neg' in likelihood and i['target'][start_pos] == -1:
                     self.assertTrue(i['ntarget'][start_pos] != -1)
@@ -65,7 +68,7 @@ class TestDataLoader(unittest.TestCase):
         for likelihood in ['onebyone', 'onebyone-neg', 'onebyone-pos', 'onebyone-both']:
             output = []
             for i in tfkit.gen_onebyone.loadOneByOneDataset(os.path.join(TestDataLoader.DATASET_DIR, 'generate.csv'),
-                                                            pretrained='openai-gpt',
+                                                            pretrained_config='openai-gpt',
                                                             maxlen=maxlen, likelihood=likelihood):
                 start_pos = i['start']
                 output.append(tokenizer.convert_ids_to_tokens(i['target'])[start_pos])
@@ -77,7 +80,15 @@ class TestDataLoader(unittest.TestCase):
         for i in tfkit.classifier.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'classification.csv')):
             print(i)
         for i in tfkit.classifier.loadClassifierDataset(os.path.join(TestDataLoader.DATASET_DIR, 'classification.csv'),
-                                                        pretrained='bert-base-chinese',
+                                                        pretrained='voidful/albert_chinese_small',
+                                                        maxlen=512):
+            self.assertTrue(len(i['input']) <= 512)
+            self.assertTrue(len(i['target']) < 512)
+
+        for i in tfkit.classifier.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'multi_label_classification.csv')):
+            print(i)
+        for i in tfkit.classifier.loadClassifierDataset(os.path.join(TestDataLoader.DATASET_DIR, 'multi_label_classification.csv'),
+                                                        pretrained='voidful/albert_chinese_small',
                                                         maxlen=512):
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) < 512)
@@ -86,28 +97,26 @@ class TestDataLoader(unittest.TestCase):
         for i in tfkit.qa.get_data_from_file(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv')):
             print(i)
         for i in tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
-                                        pretrained='bert-base-chinese',
+                                        pretrained='voidful/albert_chinese_small',
                                         maxlen=512):
-            print(i['raw_input'][int(i['target'][0]):int(i['target'][1])])
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) == 2)
         for i in tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
                                         pretrained='voidful/albert_chinese_tiny',
                                         maxlen=512):
-            print(i['raw_input'][int(i['target'][0]):int(i['target'][1])])
             self.assertTrue(len(i['input']) <= 512)
             self.assertTrue(len(i['target']) == 2)
 
     def testLen(self):
         ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
-                                    pretrained='bert-base-chinese',
+                                    pretrained='voidful/albert_chinese_small',
                                     maxlen=512)
         print(ds.__len__())
         ds.increase_with_sampling(20)
         self.assertTrue(ds.__len__() == 20)
 
         ds = tfkit.qa.loadQADataset(os.path.join(TestDataLoader.DATASET_DIR, 'qa.csv'),
-                                    pretrained='bert-base-chinese',
+                                    pretrained='voidful/albert_chinese_small',
                                     maxlen=512)
         print(ds.__len__())
         ds.increase_with_sampling(12)
